---
name: Question
about: Ask an advice on how to do something
title: ''
labels: 'question'
assignees: ''

---
## Question

<!-- What problem do you currently face and see no solution for it? -->

<!-- If possible, explain what other ways did you try to solve the problem? -->


## Checklist

- [ ] I have read the [documentation](https://kopf.readthedocs.io/en/latest/) and searched there for the problem
- [ ] I have searched in the [GitHub Issues](https://github.com/nolar/kopf/issues?utf8=%E2%9C%93&q=) for similar questions


## Keywords

<!-- Which keywords did you search for in the documentation/issue for this problem? -->
